package VMOMI::DiagnosticManagerLogCreator;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
